package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.KeyProject;

/**
 * 重点工程Mapper接口
 * 
 * @author ruoyi
 * @date 2023-07-24
 */
public interface KeyProjectMapper 
{
    /**
     * 查询重点工程
     * 
     * @param id 重点工程主键
     * @return 重点工程
     */
    public KeyProject selectKeyProjectById(Long id);

    /**
     * 查询重点工程列表
     * 
     * @param keyProject 重点工程
     * @return 重点工程集合
     */
    public List<KeyProject> selectKeyProjectList(KeyProject keyProject);

    /**
     * 新增重点工程
     * 
     * @param keyProject 重点工程
     * @return 结果
     */
    public int insertKeyProject(KeyProject keyProject);

    /**
     * 修改重点工程
     * 
     * @param keyProject 重点工程
     * @return 结果
     */
    public int updateKeyProject(KeyProject keyProject);

    /**
     * 删除重点工程
     * 
     * @param id 重点工程主键
     * @return 结果
     */
    public int deleteKeyProjectById(Long id);

    /**
     * 批量删除重点工程
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKeyProjectByIds(String[] ids);
}
